@@ -1,6 +1,7 @@
+from django import template
+
 import base64
 
-from django import template
 
 register = template.Library()
 
@@ -10,5 +11,7 @@ def auth_magic_link(context):
     """
     :return: context("base_url") + base64.urlsafe_b64encode(context["username")/context("token"))
     """
-    token = base64.urlsafe_b64encode(bytes(f"{context['username']}/{context['token']}", "utf-8")).decode("utf-8")
+    token = base64.urlsafe_b64encode(
+        bytes(f"{context['username']}/{context['token']}", "utf-8")
+    ).decode("utf-8")
     return f"{context['base_url']}{token}"
